##  Overview
The goal of this tutorial is to provide a working example of how 'runs' of the SAP LeanIX Integration API can be initiated from a 3rd party system using Python.
**Note**
Command Line Interface (CLI) Version
This tutorial involves modifying/assigning variables in a Python script. For a version of this that can be executed in the CLI without directly modifying code, please visit our Public Scripts [repository![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fgithub.com%2Fleanix-public%2Fscripts%2Ftree%2Fmaster%2FstartIntegrationAPIRun "https://github.com/leanix-public/scripts/tree/master/startIntegrationAPIRun").
**Note**
Processor Details
Detailed documentation about configuring Integration API connectors are not covered in this tutorial. Comprehensive documentation of the Integration API can be found [here](https://help.sap.com/docs/leanix/ea/integration-api?locale=en-US&state=PRODUCTION&version=CLOUD "Overview of the Integration API.").
